@@ -74,9 +74,30 @@ def display_data(raw_data_string, raw_data_id, model_folder):
         PROJECT_ROOT,
         feature_description['data-source'],
         "info.yml")
+    if not os.path.isfile(preprocessing_description_file):
+        logging.error("You are probably not in the folder of a model, because "
+                      "%s is not a file.", preprocessing_description_file)
+        sys.exit(-1)
     with open(preprocessing_description_file, 'r') as ymlfile:
         preprocessing_description = yaml.load(ymlfile)
 
+    # Print preprocessing queue
+    print("#### Preprocessing")
+    print("```")
+    tmp = preprocessing_description['queue']
+    preprocessing_queue = preprocessing.get_preprocessing_queue(tmp)
+    for algorithm in preprocessing_queue:
+        print("* " + str(algorithm))
+    print("```")
+
+    feature_list = features.get_features(feature_description['features'])
+    INPUT_FEATURES = sum(map(lambda n: n.get_dimension(), feature_list))
+    print("#### Features (%i)" % INPUT_FEATURES)
+    print("```")
+    for algorithm in feature_list:
+        print("* %s" % str(algorithm))
+    print("```")
+
     # Get Handwriting
     a = HandwrittenData(raw_data_string, raw_data_id=raw_data_id)
 
